<?php
/**
 * SPDX-FileCopyrightText: 2024 Sascha Nitsch (grumpydeveloper) https://contentnation.net/@grumpydevelop
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 * @author Sascha Nitsch (grumpydeveloper)
 **/

namespace Federator\Connector;

/**
 * base class for remote authentication
 */
interface Connector
{
    /**
     * get followers of given user
     *
     * @param string $id user id

     * @return \Federator\Data\FedUser[]|false
     */
    public function getRemoteFollowersOfUser($id);

    /**
     * get posts by given user
     *
     * @param string $id user id
     * @param string $min min date
     * @param string $max max date

     * @return \Federator\Data\ActivityPub\Common\APObject[]|false
     */
    public function getRemotePostsByUser($id, $min, $max);

    /**
     * get remote user by given name
     *
     * @param string $_name user/profile name
     * @return \Federator\Data\User | false
     */
    public function getRemoteUserByName(string $_name);

    /**
     * get remote user by given session
     *
     * @param string $_session session id
     * @param string $_user user/profile name
     * @return \Federator\Data\User | false
     */
    public function getRemoteUserBySession(string $_session, string $_user);

    /**
     * get statistics from remote system
     *
     * @return \Federator\Data\Stats|false
     */
    public function getRemoteStats();

    /**
     * Convert jsonData to Activity format
     *
     * @param array<string, mixed> $jsonData the json data from our platfrom
     * @return \Federator\Data\ActivityPub\Common\Activity|false
     */
    public function jsonToActivity(array $jsonData);

    /**
     * check if the headers include a valid signature
     *
     * @param string[] $headers the headers
     * @throws \Federator\Exceptions\PermissionDenied
     * @return string|\Federator\Exceptions\PermissionDenied
     */
    public function checkSignature($headers);
}
