<?php
/**
 * SPDX-FileCopyrightText: 2024 Sascha Nitsch (grumpydeveloper) https://contentnation.net/@grumpydevelop
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 * @author Sascha Nitsch (grumpydeveloper)
 **/

namespace Federator\Data\ActivityPub\Common;

class Activity extends APObject
{
    // actor | object | target | result | origin | instrument
    /**
     * actor
     *
     * @var APObject $actor
     */
    private $actor = null;

    /**
     * aactor
     *
     * @var string $aactor
     */
    private $aactor = '';

    /**
     * constructor
     *
     * @param ?string $type type
     */
    public function __construct($type = null)
    {
        parent::__construct($type ?? "Activity");
    }

    /**
     * set actor
     *
     * @param string $actor new actor
     * @return Activity
     */
    public function setAActor(string $actor)
    {
        $this->aactor = $actor;
        return $this;
    }

    public function getAActor() : string
    {
        return $this->aactor;
    }

    /**
     * set actor
     *
     * @param APObject $actor new actor
     * @return Activity
     */
    public function setActor($actor)
    {
        $this->actor = $actor;
        return $this;
    }

    /**
     * create from json/array
     *
     * @param mixed $json
     * @return bool true on success
     */
    public function fromJson($json)
    {
        if (array_key_exists('actor', $json)) {
            $this->actor = $json['actor'];
            $this->aactor = $json['actor'];
            unset($json['actor']);
        }
        if (!parent::fromJson($json)) {
            return false;
        }
        return true;
    }

    /**
     * convert internal state to php array
     *
     * @return array<string,mixed>
     */
    public function toObject()
    {
        $return = parent::toObject();
        if ($this->actor !== null) {
            $return['actor'] = $this->actor;
        }
        if ($this->aactor !== '') {
            $return['actor'] = $this->aactor;
        }
        return $return;
    }

    /**
     * get Child Object
     *
     * @return APObject|string|null
     */
    public function getObject()
    {
        return parent::getObject();
    }
}
