<?php
/**
 * SPDX-FileCopyrightText: 2024 Sascha Nitsch (grumpydeveloper) https://contentnation.net/@grumpydevelop
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 * @author Sascha Nitsch (grumpydeveloper)
 **/

namespace Federator\Data\ActivityPub;

/**
 * Factory class for creating various ActivityPub classes
 */
class Factory
{

    /**
     * create object tree from json
     * @param array<string, mixed> $json input json
     * @return Common\APObject|null object or false on error
     */
    public static function newFromJson($json, string $jsonstring)
    {
        if (gettype($json) !== "array") {
            error_log("newFromJson called with ".gettype($json). " => ". debug_backtrace()[1]['function']
            . " json: " . print_r($json, true));
            return null;
        }
        if (!array_key_exists('type', $json)) {
            return null;
        }
        $return = null;
        switch ($json['type']) {
            case 'Announce':
                $return = new Common\Announce();
                break;
            case 'Article':
                $return = new Common\Article();
                break;
            /*case 'Document':
                $return = new Common\Document();
                break;
            case 'Event':
                $return = new Common\Event();
                break;*/
            case 'Follow':
                $return = new Common\Follow();
                break;
            case 'Image':
                $return = new Common\Image();
                break;
            case 'Note':
                $return = new Common\Note();
                break;
            case 'Outbox':
                $return = new Common\Outbox();
                break;
            case 'Inbox':
                $return = new Common\Inbox();
                break;
            /*case 'Question':
                $return = new Common\Question();
                break;
            case 'Video':
                $return = new Common\Video();
                break;*/
            default:
                error_log("newFromJson: unknown type: '" . $json['type'] . "' " . $jsonstring);
                error_log(print_r($json, true));
        }
        if ($return !== null && $return->fromJson($json)) {
            return $return;
        }
        return null;
    }

    /**
     * create object tree from json
     * @param array<string, mixed> $json input json
     * @return Common\Activity|false object or false on error
     */
    public static function newActivityFromJson($json)
    {
        if (!array_key_exists('type', $json)) {
            return false;
        }
        //$return = false;
        switch ($json['type']) {
            case 'Accept':
                $return = new Common\Accept();
                break;
            case 'Announce':
                $return = new Common\Announce();
                break;
            case 'Create':
                $return = new Common\Create();
                break;
            case 'Delete':
                $return = new Common\Delete();
                break;
            case 'Follow':
                $return = new Common\Follow();
                break;
            case 'Reject':
                $return = new Common\Reject();
                break;
            case 'Undo':
                $return = new Common\Undo();
                break;
            default:
                error_log("newActivityFromJson " . print_r($json, true));
        }
        if (isset($return) && $return->fromJson($json) !== null) {
            return $return;
        }
        return false;
    }
}
