<?php
/**
 * SPDX-FileCopyrightText: 2024 Sascha Nitsch (grumpydeveloper) https://contentnation.net/@grumpydevelop
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 * @author Yannis Vogel (vogeldevelopment)
 **/

namespace Federator\Data;

/**
 * storage class for user attributes
 */
class FedUser
{
    /**
     * user id
     *
     * @var string $id
     */
    public $id;

    /**
     * user url
     *
     * @var string $actorURL
     */
    public $actorURL;

    /**
     * user name
     *
     * @var string $name
     */
    public $name = '';

    /**
     * user public key
     *
     * @var string $publicKey
     */
    public $publicKey;

    /**
     * summary for user/profile
     *
     * @var string $summary
     */
    public $summary = '';

    /**
     * type of user (person/group)
     *
     * @var string $type
     */
    public $type = 'Person';

    /**
     * inbox URL
     *
     * @var string $inboxURL
     */
    public $inboxURL;

    /**
     * shared inbox URL
     *
     * @var string $sharedInboxURL
     */
    public $sharedInboxURL;

    /**
     * followers URL
     *
     * @var string $followersURL
     */
    public $followersURL;

    /**
     * following URL
     *
     * @var string $followingURL
     */
    public $followingURL;

    /**
     * public key ID
     *
     * @var string $publicKeyId
     */
    public $publicKeyId;

    /**
     * outbox URL
     *
     * @var string $outboxURL
     */
    public $outboxURL;

    /**
     * create new user object from json string
     *
     * @param string $input input string
     * @return FedUser|false
     */
    public static function createFromJson($input)
    {
        $data = json_decode($input, true);
        if ($data === null) {
            return false;
        }
        $user = new FedUser();
        $user->id = $data['id'] ?? '';
        $user->actorURL = $data['actorURL'] ?? '';
        $user->name = $data['name'] ?? '';
        $user->publicKey = $data['publicKey'] ?? '';
        $user->summary = $data['summary'] ?? '';
        $user->type = $data['type'] ?? 'Person';
        $user->inboxURL = $data['inbox'] ?? '';
        $user->sharedInboxURL = $data['sharedInbox'] ?? '';
        $user->followersURL = $data['followers'] ?? '';
        $user->followingURL = $data['following'] ?? '';
        $user->publicKeyId = $data['publicKeyId'] ?? '';
        $user->outboxURL = $data['outbox'] ?? '';
        return $user;
    }

    /**
     * convert internal data to json string
     *
     * @return string
     */
    public function toJson()
    {
        $data = [
            'id' => $this->id,
            'actorURL' => $this->actorURL,
            'name' => $this->name,
            'publicKey' => $this->publicKey,
            'summary' => $this->summary,
            'type' => $this->type,
            'inbox' => $this->inboxURL,
            'sharedInbox' => $this->sharedInboxURL,
            'followers' => $this->followersURL,
            'following' => $this->followingURL,
            'publicKeyId' => $this->publicKeyId,
            'outbox' => $this->outboxURL,
        ];
        return json_encode($data) ?: '';
    }
}
