<?php

namespace Federator\Jobs;

class InboxJob
{
    /** @var array<string, mixed> $args Arguments for the job */
    public $args = [];

    /**
     * cache instance
     *
     * @var \Federator\Cache\Cache $cache
     */
    protected $cache;

    /**
     * remote connector
     *
     * @var \Federator\Connector\Connector $connector
     */
    protected $connector = null;

    /**
     * database instance
     *
     * @var \Mysqli $dbh
     */
    protected $dbh;

    /**
     * Set up environment for this job
     */
    public function setUp(): void
    {
        $contentnation = new \Federator\Api();
        $contentnation->openDatabase();
        $contentnation->loadPlugins();

        // Recreate dependencies as needed
        $this->dbh = $contentnation->getDatabase(); // get DB connection
        $this->connector = $contentnation->getConnector(); // get connector
        $this->cache = $contentnation->getCache(); // get cache
    }

    /**
     * Perform the inbox job.
     *
     * @return bool true on success, false on failure
     */
    public function perform(): bool
    {
        error_log("InboxJob: Starting inbox job");
        $user = $this->args['user'];
        $activity = $this->args['activity'];

        $inboxActivity = \Federator\Data\ActivityPub\Factory::newActivityFromJson($activity);

        if ($inboxActivity === false) {
            error_log("InboxJob: Failed to create inboxActivity from JSON");
            return false;
        }

        \Federator\Api\FedUsers\Inbox::postForUser($this->dbh, $this->connector, $this->cache, $user, $inboxActivity);
        return true;
    }
}